@@ -2,7 +2,7 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.1'
+__version__ = '0.1.3'
 
 from scapy.all import *
 import struct
@@ -24,11 +24,13 @@ def packet_summary(pkt):
 
 class DataOut(object):
     def __init__(self, serial,
+                 terminal_type=None,
                  src_ip=None, dst_ip=None,
                  tcp_sport=None, tcp_dport=None,
                  src_mac=None, dst_mac=None,
                  time=None):
         self.serial = serial
+        self.terminal_type = terminal_type
         self.src_ip = src_ip
         self.dst_ip = dst_ip
         self.tcp_sport = tcp_sport
@@ -39,6 +41,7 @@ class DataOut(object):
 
     def __dict__(self):
         return dict(serial=self.serial,
+                    terminal_type=self.terminal_type,
                     src_ip=self.src_ip,
                     dst_ip=self.dst_ip,
                     tcp_sport=self.tcp_sport,
@@ -52,6 +55,23 @@ class DataOut(object):
         return str(self.__dict__())
 
 
+def get_ruptela_serial(packet):
+    data = b''.join(struct.unpack_from('>8c', bytes(packet), offset=68))
+    serial = int.from_bytes(data, byteorder='big')
+    return str(serial)
+
+
+def get_teltonika_serial(packet):
+    serial_length = struct.unpack_from('>b', bytes(packet), offset=67)[0]
+    if len(packet) > 100:
+        return None
+    if serial_length < 15:
+        return None
+    fmt = ">{}s".format(str(serial_length))
+    serial = struct.unpack_from(fmt, bytes(packet), offset=68)[0].decode('utf8')
+    return serial
+
+
 def parse_file(args):
     packets = rdpcap(args.filename)
     myip = args.filter_dst_ip
@@ -59,16 +79,23 @@ def parse_file(args):
         packets = packets.filter(lambda x: x.payload.dst == myip)
     # Let's iterate through every filtered packet
     for packet in packets:
-        if len(packet) > 100:
-            continue
         try:
             packet_summ = packet_summary(packet)
-            serial_lenght = struct.unpack_from('>b', bytes(packet), offset=67)[0]
-            if serial_lenght < 15:
+            t_serial = get_teltonika_serial(packet)
+            r_serial = get_ruptela_serial(packet)
+            if t_serial:
+                terminal_type = "Teltonika"
+                serial = t_serial
+            elif r_serial:
+                terminal_type = "Ruptela"
+                serial = r_serial
+            else:
+                serial = "Bad_serial"
+            if len(serial) < 15 or len(serial) > 15:
                 continue
-            fmt = ">{}s".format(str(serial_lenght))
-            serial = struct.unpack_from(fmt, bytes(packet), offset=68)[0].decode('utf8')
+
             payload = DataOut(serial,
+                              terminal_type,
                               *packet_summ
                               )
             print(payload)
