@@ -11,9 +11,9 @@ def parse_args():
     parser.add_argument('-m', '--filter_dst_ip')
     return parser.parse_args()
 
-def main(args):
-    return parse_file(args)
+def main():
+    return parse_file(parse_args())
 
 
 if __name__ == "__main__":
-    sys.exit(main(parse_args()))  # pragma: no cover
+    sys.exit(main())  # pragma: no cover
